@@ -87,19 +87,23 @@ class FomKeycloak:
         # return username / email
         matchedUsers = []
         for user in users:
-
-            if user['username'].lower().startswith(userId.lower()):
+            # search for username
+            #if user['username'].lower().startswith(userId.lower()):
+            if userId.lower() in user['username'].lower():
                 email = ''
-                if email in user:
+                if 'email' in user:
                     email = user['email']
                 matchedUsers.append([user['username'], email])
-            elif ('email' in user) and user['email'].lower().startswith(
-                    userId.lower()):
+            # search matching email
+            #elif ('email' in user) and user['email'].lower().startswith(
+            #        userId.lower()):
+            elif ('email' in user) and userId.lower() in user['email'].lower():
+
                 matchedUsers.append([user['username'], user['email']])
             elif (('attributes' in user) and
                   'idir_username' in user['attributes']) and \
-                    user['attributes']['idir_username'][0].lower().startswith(
-                        userId.lower()):
+                    userId.lower() in user['attributes']['idir_username'][0].lower():
+
                 matchedUsers.append([user['username'], user['email']])
 
         LOGGER.debug(f"users: {users}")
