@@ -1,4 +1,8 @@
-from . import fomuser
+try:
+    from . import fomuser
+except ImportError:
+    import fomuser
+
 if __name__ == '__main__':
     cli = fomuser.CLI()
     cli.defineParser()
